/*
 ** 报表的编辑、新增表单
 ** create by ChenLong on 2022/8/10
 ** 功能路径：src\pages\product\ReportsManage\ReportEditForm.js
 ** 菜单参数列表：*变量名*(变量说明，数据类型，是否必填，取值范围)
 **/
import React, { useEffect, useState } from 'react';
import { Form, Input, DatePicker, InputNumber, Space, Row, Col, Button, message } from 'antd';
import moment from 'moment';
import { submitReportData } from './api/service/report';
// 类型
const DATE_PICKER_ARRAY = ['日期'];
const DATE_TIME_PICKER_ARRAY = ['日期时刻'];
const DATE_TYPE = ['日期', '日期时刻']; // 用来匹配是否需要转为日期对象；
const NUMBER_ARRAY = ['数值', '金额'];
// 形态对应组件

// 对应关系

/**
 * @description: 函数描述
 * @date: 2022/8/10
 * @author: ChenLong
 * @params: reportDetails 各个字段的配置列表
 *           data 与reportDetails对应的值
 */
const ReportEditForm = ({ reportDetails, reportData, onCancel, reportName }) => {
  if (!reportData || Object.keys(reportData).length === 0) return <>未传递表单数据</>;
  const [form] = Form.useForm();
  const formItemLayout = {
    labelCol: {
      span: 8,
    },
    wrapperCol: {
      span: 16,
    },
  };
  const handleDate = (reportDetails, data) => {
    let _data = { ...data };
    reportDetails.forEach((item) => {
      if (DATE_TYPE.includes(item.type)) {
        _data[item.fieldAlias] = moment(data[item.fieldAlias]);
      }
    });
    return _data;
  };
  const componentMap = (config) => {
    if (DATE_TIME_PICKER_ARRAY.includes(config.type)) {
      return <DatePicker showTime />;
    } else if (DATE_PICKER_ARRAY.includes(config.type)) {
      return <DatePicker />;
    } else if (NUMBER_ARRAY.includes(config.type)) {
      return <InputNumber />;
    } else {
      return <Input />;
    }
  };
  const submitReportForm = () => {
    let _data = form.getFieldsValue();
    console.log(_data);
    // {
    //   "key": "string",
    //   "fieldName": "string",
    //   "fieldValue": "string"
    // }
    let final = [];
    Object.keys(_data).forEach((key) => {
      let value = reportData[key];
      let _value = _data[key];
      if (moment.isMoment(_data[key])) {
        _value = moment(_data[key]).format('YYYY-MM-DD HH:mm:ss');
      }
      if (value !== _value) {
        final.push({
          key: reportData.Key,
          fieldName: key,
          fieldValue: _value,
        });
      }
    });
    console.log(final);
    // reportService.updateReportData()
    submitReportData(
      {
        reportName: reportName,
        userId: window.globalConfig.userInfo.OID,
      },
      final,
    ).then((res) => {
      if (res.code === 0) {
        message.success('保存成功！');
        onCancel();
      }
    });
  };
  useEffect(() => {
    if (reportData && Object.keys(reportData).length)
      form.setFieldsValue(handleDate(reportDetails, reportData));
  }, [reportData]);
  return (
    <div>
      <Form {...formItemLayout} form={form}>
        <Row>
          {reportDetails &&
            reportDetails.map((config) => {
              return (
                <Col span={8}>
                  <Form.Item label={config.fieldAlias} name={config.fieldAlias}>
                    {componentMap(config)}
                  </Form.Item>
                </Col>
              );
            })}
        </Row>
        <Row>
          <Col span={24} style={{ textAlign: 'right' }}>
            {/*<Form.Item style={{textAlign:'right'}}>*/}
            <Button type={'primary'} onClick={submitReportForm}>
              提交
            </Button>
            {/*</Form.Item>*/}
          </Col>
        </Row>
      </Form>
    </div>
  );
};
export default ReportEditForm;
