const isObject = (obj) => {
  return Object.prototype.toString.call(obj) === '[object Object]';
};
const isString = (obj) => {
  return Object.prototype.toString.call(obj) === '[object String]';
};
const isNumber = (num) => {
  return Object.prototype.toString.call(num) === '[object Number]';
};
const isArray = (arr) => {
  return Object.prototype.toString.call(arr) === '[object Array]';
};
const hasMoney = (configItems) => {
  if (!configItems) return false;
  let _items = configItems.split('|');
  return !!_items.find((item) => item === '金额');
};
/**
 * @description: 用来在summary中处理数值的配置
 * @params: 参数描述
 * @date: 2022/8/10
 * @author: ChenLong
 */
const returnHandledNumber = (configItems, num) => {
  // 精度、前缀、后缀、倍率
  // $_d|_d%|_d*0.0001|金额|0.00
  if (!configItems) return num;
  let _items = configItems.split('|');
  /*  let prefix = '';
    let suffix = '';*/
  let template = '_d';
  let precision = 0;
  let rate = 1;
  _items.forEach((item) => {
    let _arr = [];
    if (item.match(/_d[^\*]/)) {
      // 后缀
      template = item;
    } else if (item.match(/^_d\*/)) {
      // 倍率
      let _rate = item.replace(/_d\*/, '');
      rate = _rate ? Number(_rate) : 1;
    } else if (item.match(/^0\./)) {
      // 精度
      precision = item.replace('0.', '').length;
    }
  });
  // 可能存在NaN的问题
  let final = _items.includes('金额')
    ? Number((num * rate).toFixed(precision)).toLocaleString()
    : Number((num * rate).toFixed(precision));
  return template.replace(/_d/, final);
};
/**
 * @description: 返回configItems内配置的默认值、默认模式等等
 * @params: 参数描述
 * @date: 2022/8/12
 * @author: ChenLong
 * @params:
 *  configItems 报表字段的配置 例如 defaultValue=智慧水务
 *     defaultDateModel=customer|defaultDateValue=2022-01-01,2022-12-31;
 *           keysArray
 *     所需要返回的值的key的集合，比如你需要获取configItems中的’defaultValue‘，那么keysArray=['defaultValue'];
 * @returns:
 *  defaultValue 通用参数 默认值
 *          defaultDateModel 时间参数 默认模式
 *          defaultDateValue 时间参数 默认时间
 */
const returnDefaultValueOrConfigs = (configItems = '', keysArray = []) => {
  let _map = {};
  let _configItemsArray = configItems.split('|');
  keysArray.forEach((key) => {
    _map[key] = _configItemsArray.find((item) => item.includes(`${key}=`))?.replace(`${key}=`, '');
  });
  return _map;
};
export {
  isObject,
  isString,
  isNumber,
  hasMoney,
  isArray,
  returnHandledNumber,
  returnDefaultValueOrConfigs,
};
